@@ -8,7 +8,7 @@ use PYX::SGML::Tags;
 use Tags::Output::Indent;
 use Tags::Output::Raw;
 
-our $VERSION = 0.03;
+our $VERSION = 0.04;
 
 # Constructor.
 sub new {
@@ -99,23 +99,21 @@ App::PYX2XML - Perl class for pyx2xml application.
 
 =head1 METHODS
 
-=over 8
+=head2 C<new>
 
-=item C<new()>
+ my $obj = App::PYX2XML->new;
 
- Constructor.
+Constructor.
 
-=item C<run()>
+Returns instance of object.
 
- Run.
+=head2 C<run>
 
-=back
+ $obj->run;
 
-=head1 ERRORS
+Run.
 
- new():
-         From Class::Utils:
-                 Unknown parameter '%s'.
+Returns undef.
 
 =head1 EXAMPLE
 
@@ -161,6 +159,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.03
+0.04
 
 =cut
